yaml = '''# image:
#   repository: kubernetesui/dashboard
protocolHttp: true
rbac:
  create: true
  clusterRoleMetrics: true
serviceAccount:
  create: false
  name: th2infra-kubernetes-dashboard 
ingress:
  enabled: true
  annotations:
    kubernetes.io/ingress.class: "nginx"
    nginx.ingress.kubernetes.io/rewrite-target: $1
    nginx.ingress.kubernetes.io/configuration-snippet: rewrite ^/([a-z\-0-9]*)$ $scheme://$http_host/$1/ redirect;
  paths:
    - /dashboard($|/.*)
  hosts: [<hosts>]'''